Module component

Module component 

Traits

Component
The Component Interface for allowing Component based data structures like the ComponentStack to store components with various purposes and implementations to work together.